#!/bin/bash

command -v rpmspec || dnf install /usr/bin/rpmspec || { echo "rpmspec absent";exit 1; }
rpm -q npm || dnf install npm || { echo "npm absent"; exit 1; }

spec_file="js-d3-flame-graph.spec"

rpmspec -P ${spec_file} > ./tmp_spec
[ $? -eq 0 ] || { echo "rpmspec failed"; exit 1; }

name=$(grep '^Name:' ./tmp_spec | awk '{print $2}')
version=$(grep '^Version:' ./tmp_spec | awk '{print $2}')
source0=$(grep '^Source0:' ./tmp_spec | awk '{print $2}')
source1=$(grep '^Source1:' ./tmp_spec | awk '{print $2}')

source0_tarball_name=$(basename "${source0}")
wget "${source0}" -q --show-progress -O ${source0_tarball_name}
[ $? -eq 0 ] || { echo "wget source0 failed"; exit 1; }
tar -xvf "${source0_tarball_name}"

source0_tarball_dir=${source0_tarball_name%*.tar.gz}
cd "${source0_tarball_dir}"
npm install || { echo "npm failed"; exit 1; }
cd ..

tar -cvf "${source1}" "${source0_tarball_dir}"/node_modules

# requires from package.json and version of installed requires from package-lock.json
python3 ./get_package_list.py ${source0_tarball_dir}/package.json dependencies > ./dependencies_list
python3 ./get_package_list.py ${source0_tarball_dir}/package.json devDependencies >> ./dependencies_list
echo > ./dependencies_version
while read line; do
    python3 ./get_package_version_installed.py ${source0_tarball_dir}/package-lock.json $line >> ./dependencies_version
done < ./dependencies_list

sh ./update_privoders.sh ${spec_file} ./dependencies_version

rm -f ./tmp_spec ./dependencies_list ./dependencies_version
rm -rf ${source0_tarball_dir}
